==> jc-1.4.0.tar.gz: soot/tagkit/PositionTag.h <==
// public class soot.tagkit.PositionTag

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 4f112a0e13b029d9 soot_tagkit_PositionTag

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_tagkit_PositionTag_H_
#define _JC_soot_tagkit_PositionTag_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_soot_tagkit_PositionTag$sub_refs	_jc_soot_tagkit_PositionTag$sub_refs;
typedef struct _jc_soot_tagkit_PositionTag$sub_nonrefs	_jc_soot_tagkit_PositionTag$sub_nonrefs;
typedef struct _jc_soot_tagkit_PositionTag$refs	_jc_soot_tagkit_PositionTag$refs;
typedef struct _jc_soot_tagkit_PositionTag$nonrefs	_jc_soot_tagkit_PositionTag$nonrefs;
typedef struct _jc_soot_tagkit_PositionTag$object	_jc_soot_tagkit_PositionTag$object;

typedef const struct _jc_soot_tagkit_PositionTag$vmethods	_jc_soot_tagkit_PositionTag$vmethods;
typedef const struct _jc_soot_tagkit_PositionTag$vtable	_jc_soot_tagkit_PositionTag$vtable;
typedef const struct _jc_soot_tagkit_PositionTag$vtype	_jc_soot_tagkit_PositionTag$vtype;

// Constructors
extern void _jc_soot_tagkit_PositionTag$method$_init$02b806c1c13eed5e(_jc_env *, struct _jc_soot_tagkit_PositionTag$object *, jint, jint);

// Virtual methods
extern jint _jc_soot_tagkit_PositionTag$method$getEndOffset$4d0dd90be96a6f35(_jc_env *, struct _jc_soot_tagkit_PositionTag$object *);
extern struct _jc_java_lang_String$object *_jc_soot_tagkit_PositionTag$method$getName$bec186f2ce7e1882(_jc_env *, struct _jc_soot_tagkit_PositionTag$object *);
extern jint _jc_soot_tagkit_PositionTag$method$getStartOffset$2827f75ce05b8912(_jc_env *, struct _jc_soot_tagkit_PositionTag$object *);
extern _jc_byte_array *_jc_soot_tagkit_PositionTag$method$getValue$824c7561d2f47329(_jc_env *, struct _jc_soot_tagkit_PositionTag$object *);
extern struct _jc_java_lang_String$object *_jc_soot_tagkit_PositionTag$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_tagkit_PositionTag$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_tagkit_PositionTag$method_info$getEndOffset$4d0dd90be96a6f35;
extern _jc_method _jc_soot_tagkit_PositionTag$method_info$getName$bec186f2ce7e1882;
extern _jc_method _jc_soot_tagkit_PositionTag$method_info$getStartOffset$2827f75ce05b8912;
extern _jc_method _jc_soot_tagkit_PositionTag$method_info$getValue$824c7561d2f47329;
extern _jc_method _jc_soot_tagkit_PositionTag$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_tagkit_PositionTag$vmethods {
	jint	(*getEndOffset$4d0dd90be96a6f35)(_jc_env *, struct _jc_soot_tagkit_PositionTag$object *);
	struct _jc_java_lang_String$object	*(*getName$bec186f2ce7e1882)(_jc_env *, struct _jc_soot_tagkit_PositionTag$object *);
	jint	(*getStartOffset$2827f75ce05b8912)(_jc_env *, struct _jc_soot_tagkit_PositionTag$object *);
	_jc_byte_array	*(*getValue$824c7561d2f47329)(_jc_env *, struct _jc_soot_tagkit_PositionTag$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_tagkit_PositionTag$object *);
};

// Vtable
struct _jc_soot_tagkit_PositionTag$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_tagkit_PositionTag$vmethods	soot_tagkit_PositionTag;
};

// Vtype
struct _jc_soot_tagkit_PositionTag$vtype {
	_jc_type			type;
	_jc_soot_tagkit_PositionTag$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_tagkit_PositionTag$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_tagkit_PositionTag$refs {
    _jc_soot_tagkit_PositionTag$sub_refs	soot_tagkit_PositionTag;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_tagkit_PositionTag$sub_nonrefs {
	jint	endOffset;
	jint	startOffset;
};

// Non-reference instance fields (object)
struct _jc_soot_tagkit_PositionTag$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_tagkit_PositionTag$sub_nonrefs	soot_tagkit_PositionTag;
};

// Object instance structure
struct _jc_soot_tagkit_PositionTag$object {
	_jc_soot_tagkit_PositionTag$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_tagkit_PositionTag$vtype	*vtype;
	_jc_soot_tagkit_PositionTag$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_tagkit_PositionTag$vtype _jc_soot_tagkit_PositionTag$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_tagkit_PositionTag, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_tagkit_PositionTag$class_object;

#endif	/* _JC_soot_tagkit_PositionTag_H_ */

==> jc-1.4.6.tar.gz: soot/tagkit/PositionTag.h <==
// public class soot.tagkit.PositionTag

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 4f112a0e13b029d9 soot_tagkit_PositionTag

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_tagkit_PositionTag_H_
#define _JC_soot_tagkit_PositionTag_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_soot_tagkit_PositionTag$sub_refs	_jc_soot_tagkit_PositionTag$sub_refs;
typedef struct _jc_soot_tagkit_PositionTag$sub_nonrefs	_jc_soot_tagkit_PositionTag$sub_nonrefs;
typedef struct _jc_soot_tagkit_PositionTag$refs	_jc_soot_tagkit_PositionTag$refs;
typedef struct _jc_soot_tagkit_PositionTag$nonrefs	_jc_soot_tagkit_PositionTag$nonrefs;
typedef struct _jc_soot_tagkit_PositionTag$object	_jc_soot_tagkit_PositionTag$object;

typedef const struct _jc_soot_tagkit_PositionTag$vmethods	_jc_soot_tagkit_PositionTag$vmethods;
typedef const struct _jc_soot_tagkit_PositionTag$vtable	_jc_soot_tagkit_PositionTag$vtable;
typedef const struct _jc_soot_tagkit_PositionTag$vtype	_jc_soot_tagkit_PositionTag$vtype;

// Constructors
extern void _jc_soot_tagkit_PositionTag$method$_init$02b806c1c13eed5e(_jc_env *, struct _jc_soot_tagkit_PositionTag$object *, jint, jint) _JC_JCNI_ATTR;

// Virtual methods
extern jint _jc_soot_tagkit_PositionTag$method$getEndOffset$4d0dd90be96a6f35(_jc_env *, struct _jc_soot_tagkit_PositionTag$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_soot_tagkit_PositionTag$method$getName$bec186f2ce7e1882(_jc_env *, struct _jc_soot_tagkit_PositionTag$object *) _JC_JCNI_ATTR;
extern jint _jc_soot_tagkit_PositionTag$method$getStartOffset$2827f75ce05b8912(_jc_env *, struct _jc_soot_tagkit_PositionTag$object *) _JC_JCNI_ATTR;
extern _jc_byte_array *_jc_soot_tagkit_PositionTag$method$getValue$824c7561d2f47329(_jc_env *, struct _jc_soot_tagkit_PositionTag$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_soot_tagkit_PositionTag$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_tagkit_PositionTag$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_tagkit_PositionTag$method_info$getEndOffset$4d0dd90be96a6f35;
extern _jc_method _jc_soot_tagkit_PositionTag$method_info$getName$bec186f2ce7e1882;
extern _jc_method _jc_soot_tagkit_PositionTag$method_info$getStartOffset$2827f75ce05b8912;
extern _jc_method _jc_soot_tagkit_PositionTag$method_info$getValue$824c7561d2f47329;
extern _jc_method _jc_soot_tagkit_PositionTag$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_tagkit_PositionTag$vmethods {
	jint	(*getEndOffset$4d0dd90be96a6f35)(_jc_env *, struct _jc_soot_tagkit_PositionTag$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*getName$bec186f2ce7e1882)(_jc_env *, struct _jc_soot_tagkit_PositionTag$object *) _JC_JCNI_ATTR;
	jint	(*getStartOffset$2827f75ce05b8912)(_jc_env *, struct _jc_soot_tagkit_PositionTag$object *) _JC_JCNI_ATTR;
	_jc_byte_array	*(*getValue$824c7561d2f47329)(_jc_env *, struct _jc_soot_tagkit_PositionTag$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_tagkit_PositionTag$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_tagkit_PositionTag$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_tagkit_PositionTag$vmethods	soot_tagkit_PositionTag;
};

// Vtype
struct _jc_soot_tagkit_PositionTag$vtype {
	_jc_type			type;
	_jc_soot_tagkit_PositionTag$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_tagkit_PositionTag$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_tagkit_PositionTag$refs {
    _jc_soot_tagkit_PositionTag$sub_refs	soot_tagkit_PositionTag;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_tagkit_PositionTag$sub_nonrefs {
	jint	endOffset;
	jint	startOffset;
};

// Non-reference instance fields (object)
struct _jc_soot_tagkit_PositionTag$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_tagkit_PositionTag$sub_nonrefs	soot_tagkit_PositionTag;
};

// Object instance structure
struct _jc_soot_tagkit_PositionTag$object {
	_jc_soot_tagkit_PositionTag$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_tagkit_PositionTag$vtype	*vtype;
	_jc_soot_tagkit_PositionTag$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_tagkit_PositionTag$vtype _jc_soot_tagkit_PositionTag$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_tagkit_PositionTag, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_tagkit_PositionTag$class_object;

#endif	/* _JC_soot_tagkit_PositionTag_H_ */
